@@ -117,6 +117,4 @@ def find_lib(libname):
     except:
         return -1
 def download_lib(lib):
-    os.system(sys.executable + " -m pip install " + lib + " -i https://pypi.douban.com/simple")
-a=get_newsnum()
-print(get_newstext(a[0]['url']),"\n")
\ No newline at end of file
+    os.system(sys.executable + " -m pip install " + lib + " -i https://pypi.douban.com/simple")
\ No newline at end of file
